<?php
/**
 * $Horde: mottle/edit.php,v 1.12 2005/01/03 14:35:19 jan Exp $
 * 
 * Copyright 2004-2005 Daniel Vandal <dvandal@infoteck.qc.ca>
 * Copyright 2003-2005 Eric Jon Rostetter <ericr@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 */

define('MOTTLE_BASE', dirname(__FILE__));
require_once MOTTLE_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Editor.php';
require_once 'Horde/Editor/htmlarea.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$id = Util::getFormData('motd_id');
$title = Util::getFormData('motd_title');
$post_time = Util::getFormData('motd_post_time');
$expire_time = Util::getFormData('motd_expire_time');
$text = Util::getFormData('motd_text');
$rtemode = Util::getFormData('rtemode', false);
$vars->set('rtemode', $rtemode);
$change_rtemode = Util::getFormData('change_rtemode', false);
$vars->set('change_rtemode', false);

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, '', 'compose');

$actionID = Util::getFormData('actionID', '');
if ($actionID != MOTTLE_DELETE_MOTD && (empty($title) || empty($post_time['month']) || empty($post_time['day']) || empty($post_time['year']) ||
    empty($expire_time['month']) || empty($expire_time['day']) || empty($expire_time['year']) || empty($text))) {
    if (empty($id)) {
        $actionID = MOTTLE_ADD_FORM;
    } else {
        $actionID = MOTTLE_EDIT_FORM;        
    }
}

switch ($actionID) {
 case MOTTLE_ADD_MOTD:
    Mottle::addMOTD($title, $post_time, $expire_time, $text);
    
    /* Get out of here */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    
    break;
 case MOTTLE_EDIT_MOTD:
    Mottle::updateMOTD($id, $title, $post_time, $expire_time, $text);
    
    /* Get out of here */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    
    break;
 case MOTTLE_DELETE_MOTD:
    Mottle::deleteMOTD($id);

    /* Get out of here */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    
    break;
 case MOTTLE_EDIT_FORM:
    $form->setTitle(_("Edit a message"));
    $vars->set('actionID', MOTTLE_EDIT_MOTD);
    $form->setButtons(_("Update"), true);
    break;
 default : /* MOTTLE_ADD_FORM */
    $form->setTitle(_("Insert a message"));
    $vars->set('actionID', MOTTLE_ADD_MOTD);
    $form->setButtons(_("Add"), true);
    break;    
}

$form->addHidden('', 'actionID', 'text', false);
$form->addHidden('', 'motd_id', 'text', false);
$form->addHidden('', 'rtemode', 'boolean', false);
$form->addHidden('', 'change_rtemode', 'boolean', false);

$required_fields = true;
if ($change_rtemode) {
    $required_fields = false;
}

$form->addVariable(_("Title"), 'motd_title', 'text', $required_fields);
$form->addVariable(_("Post time"), 'motd_post_time', 'monthdayyear', $required_fields);
$form->addVariable(_("Expire time"), 'motd_expire_time', 'monthdayyear', $required_fields);

/* Determine the composition type - text or HTML
 * according to the configuration file of Mottle and 
 * if the browser support this feature */
if ($browser->hasFeature('rte') && $conf['compose']['html']) {
    $rtelink = Horde::link('', _("Switch Composition Method"), '', '', "document.compose.actionID.value=''; document.compose.change_rtemode.value='1'; document.compose.rtemode.value='" . ($rtemode ? 0 : 1) . "'; document.compose.submit(); return false;");
    $rtelink .= $rtemode ? _("Switch to plain text") : _("Switch to HTML");
    $rtelink .= '</a>';
    
    $form->addVariable(_("Text") . '<br>' . $rtelink, 'motd_text', 'longtext', $required_fields);
} else {
    $form->addVariable(_("Text"), 'motd_text', 'longtext', $required_fields);
}

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    /* Do insert. */
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

/* Render the page. */
require MOTTLE_TEMPLATES . '/common-header.inc';
require MOTTLE_TEMPLATES . '/menu.inc';

if ($browser->hasFeature('rte') && $conf['compose']['html'] && $rtemode) {
    require_once 'Horde/Editor.php';
    $editor = &Horde_Editor::singleton('htmlarea', array('id' => 'motd_text'));
}

$notification->notify(array('listeners' => 'status'));

require MOTTLE_TEMPLATES . '/edit/edit.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
